import { ChangeDetectorRef, Component } from '@angular/core';
import { IonHeader, IonToolbar, IonTitle, IonContent, IonItem, IonList, IonSelect, IonSelectOption, IonLabel, IonButton, IonTextarea, AlertController, IonSegment, IonSegmentButton, ModalController } from '@ionic/angular/standalone';
import { ExploreContainerComponent } from '../explore-container/explore-container.component';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms'; // 导入 FormsModule
/** 引用：从fmode-ng库引用FmodeChatCompletion类 */
import { ChatPanelOptions, FmChatModalInput, FmodeChat, FmodeChatCompletion, FmodeChatMessage, MarkdownPreviewModule, openChatPanelModal } from 'fmode-ng';
import { Router } from '@angular/router'; // 导入 Router
import { DalleOptions, ImagineWork } from 'fmode-ng';

@Component({
  selector: 'app-tab3',
  templateUrl: 'tab3.page.html',
  styleUrls: ['tab3.page.scss'],
  standalone: true,
  imports: [IonHeader, IonToolbar, IonTitle, IonContent, ExploreContainerComponent,IonItem,IonList,IonSelect,IonSelectOption,IonButton,CommonModule,IonTextarea,FormsModule,
    MarkdownPreviewModule,IonSegment,IonSegmentButton,IonLabel,// ASR语音输入模块
    FmChatModalInput,],
})
export class Tab3Page {
  placeholderText: string = "职业：非必填\n喜好：非必填\n天气：非必填\n温度：非必填\n其他需求：显高显瘦？儒雅甜美？等";
  selectedSegment: string = 'ai-outfit'; // 默认选中的导航项
  selectedGender: string = ''; // 默认性别

  // 新增变量
  height: number | null = null; // 身高
  weight: number | null = null; // 体重
  age: number | null = null; // 年龄
  comments: string = ''; // 用户评论
    // 属性：组件内用于展示消息内容的变量
    responseMsg:any = ""
    // 用户输入提示词
    userPrompt:string = ''
    isComplete:boolean = false; // 定义完成状态属性，用来标记是否补全完成
    isGenerating: boolean = false; // 按钮状态
    imagineWork:ImagineWork|undefined
    countdownTimer: number = 0; // 计时器初始值
    timerInterval: any; // 用于存储定时器的引用
  images:Array<string> = []
    constructor(private alertController: AlertController,private modalCtrl:ModalController,
      private router:Router, private cdRef:ChangeDetectorRef) { }

  selectSegment(segment: string) {
    this.selectedSegment = segment; // 更新选中的导航项
  }

  isActivated(segment: string): boolean {
    return this.selectedSegment === segment; // 判断当前导航项是否被激活
  }

  selectGender(gender: string) {
    this.selectedGender = gender; // 更新选中的性别
  }
  async sendMessage(){
    // 如果正在生成，弹出警告框并返回
    if (this.isGenerating) {
      const alert = await this.alertController.create({
        header: '请等待AI回答完毕后再点击！',
        buttons: ['确定']
      });
      await alert.present();
      return; // 阻止继续执行
    }
    this.isComplete = false; // 重置完成状态
    this.isGenerating = true; // 开始生成时设置为 true
    this.countdownTimer = 0; // 重置计时器
    this.imagineWork=undefined;
    this.images = []; // 清空原来的图片数组
    this.userPrompt =`有一位${this.selectedGender}用户，该用户${this.age}岁，身高${this.height}cm，体重${this.weight}kg，该用户的补充说明是
    ${this.comments}，请你作为一名专业的服装穿搭大师并严格按照给定的例子格式，为该用户给出适合的服装搭配建议,再给出具体穿搭方案时里面的衣服颜色和类型一定要唯一，不要出现类似白色或绿色之类的句子。
    例子：嘿，兄弟，你的信息我收到了，让我来帮你计算一下BMI值，再给你一些穿搭方面的建议吧！

**一、计算BMI值**

BMI是衡量身体状况的一个标准，计算方法是体重除以身高的平方。你的体重是50KG，身高是170CM，所以计算结果为：BMI = 体重 ÷ 身高^² = 50KG ÷ （身高达到肩膀手臂撑起风衣帅气的分界线两小块的分界线的位置。）看起来你的BMI值在正常范围内哦！冬天穿搭可以根据你的喜好来选择啦！

**二、详细穿搭分析**

你身高适中，体重偏轻，选择穿搭时需要注意平衡整体造型，避免显得过于瘦弱。可以选择一些稍微宽松一些的衣物来增添一些层次感。同时，注意色彩的搭配，选择一些深色系的衣服来增加视觉上的厚重感。此外，配饰的选择也很关键，可以选择一些简约的项链、手链等增添时尚感。

**三、穿搭雷点分析**

避免选择过于紧身或者过于宽松的衣服款式，以免显得不够协调。颜色上尽量不要选择过于跳跃的颜色或者过多的颜色搭配，以免显得过于花哨。保持整体造型的简约大方即可。

**四、三套穿搭方案**

方案一：运动风搭配（冬季保暖为主）
外套：阿迪达斯运动系列羽绒服（保暖又时尚）
内搭：长袖运动衫（颜色可选黑色或灰色）搭配运动裤或牛仔裤皆可
鞋子：Nike运动鞋（保暖版）增添时尚感同时保暖十足。整体搭配既舒适又保暖。

方案二：休闲风搭配（日常出行）
外套：北面羽绒服系列（经典款式）搭配简约款围巾增添时尚感。内搭可以选择一件白色卫衣或者毛衣搭配普通牛仔裤即可。鞋子可以选择休闲鞋或板鞋即可打造出简约时尚的感觉。简约却不失品味是你想要的效果哦！👏

方案三：街头风搭配（逛街约会） 可尝试今年大热的李宁秋冬卫衣系列或国潮品牌的羽绒服系列作为外套。下身搭配潮流一点的牛仔裤和潮鞋就可以打造出自己的风格啦！可以添加一些饰品如帽子等来增加时尚感！帅气满分就是这种感觉！✨当然了也要兼顾自身的舒适感和承受能力来选择适合的搭配哦！上面这三套方案你喜欢吗？如果你有别的需要还可以再告诉我哦！
    `
    console.log("开始生成")
    let completion = new FmodeChatCompletion([
      {role:"system",content:""},
      {role:"user",content:this.userPrompt}
    ])
    completion.sendCompletion().subscribe((message: any) => {
      // 打印消息体
      console.log(message.content);
      // 赋值消息内容给组件内属性
      this.responseMsg = message.content;
      if (message?.complete) { // 判断message为完成状态，则设置isComplete为完成
        
          this.isComplete = true;
          
           // 图片生成
        this.startTimer(); // 启动计时器
        this.imagineWork = new ImagineWork();
        let PicturePrompt = `描述：${this.responseMsg}\n请你作为一名专业的服装绘制大师，根据描述中的方案一生成对应的服装图片。`
        let options:DalleOptions = {prompt:PicturePrompt}
        this.imagineWork?.draw(options).subscribe(work=>{
            console.log("imagineWork",work?.toJSON())
            console.log("images",work?.get("images"))
            if(work?.get("images")?.length){
              this.images = work?.get("images");
              this.stopTimer(); // 停止计时器
              this.isGenerating = false; // 生成完成后设置为 false
            }
        })
      }
  });

}

// 启动计时器
startTimer() {
  this.timerInterval = setInterval(() => {
      this.countdownTimer++; // 每秒增加计时
  }, 1000);
}

// 停止计时器
stopTimer() {
  clearInterval(this.timerInterval); // 清除定时器
}

openChat(){
  localStorage.setItem("company","E4KpGvTEto")
  let options:ChatPanelOptions = {
    roleId:"2DXJkRsjXK",
    onChatInit:(chat:FmodeChat)=>{
      console.log("onChatInit");
            console.log("预设角色",chat.role);
            chat.role.set("name","小马");
            chat.role.set("title","时尚顾问");
            chat.role.set("desc","一名亲切和蔼的时尚顾问，小马，年龄28岁");
            chat.role.set("tags",["全科","门诊"]);
            chat.role.set("avatar","https://nova-cloud.obs.cn-south-1.myhuaweicloud.com/storage/aigc/imagine/Q4Zif7fTbK-0.png")
            chat.role.set("prompt",`
#角色设定
您是一名时尚顾问，名叫晓晓，年龄28岁，热爱时尚，擅长根据用户的需求和个性推荐穿搭方案。您的风格亲切、幽默，旨在帮助用户找到最适合他们的服装搭配。

#对话环节
0破冰,跟用户打招呼，并引导用户聊穿搭话题，可以慢慢引导，不要太突兀，比如：
“今天的心情怎么样？”
1拓展话题
“你平时喜欢什么样的穿搭风格呢？有没有特别喜欢的颜色或者品牌？”
“如果有一个场合，你希望我帮你推荐搭配，比如约会、工作或休闲，你会选择哪个呢？”
“你觉得在穿搭上，最让你困扰的是什么？是搭配技巧还是风格选择呢？”
“有没有什么服装是你一直想尝试但还没有机会的？我们可以一起聊聊！”
2引导收尾
“今天聊得很开心呢！如果你还有其他问题或者想法，随时可以告诉我哦。”
“如果你觉得今天的聊天已经足够了，我也很乐意下次再和你聊更多时尚的话题！”
“希望你能找到自己喜欢的穿搭风格，期待下次再见！”`);
    },
    onMessage:(chat:FmodeChat,message:FmodeChatMessage)=>{
      console.log("onMessage",message)
      let content:any = message?.content
      if(typeof content == "string"){
        if(content?.indexOf("[完成]")>-1){
          console.log("聊天已完成")
        }
      }
    },
    onChatSaved:(chat:FmodeChat)=>{
      // chat?.chatSession?.id 本次会话的 chatId
      console.log("onChatSaved",chat,chat?.chatSession,chat?.chatSession?.id)
    }
  }
  openChatPanelModal(this.modalCtrl,options)
}


restoreChat(chatId:string){
  let options:ChatPanelOptions = {
    roleId:"2DXJkRsjXK",
    chatId:chatId
  }
  openChatPanelModal(this.modalCtrl,options)
}


}